========================
Salt 0.9.2 Release Notes
========================

Salt 0.9.2 has arrived! 0.9.2 is primarily a bugfix release, the exciting
component in 0.9.2 is greatly improved support for salt states. All of the
salt states interfaces have been more thoroughly tested and the new salt-states
git repo is growing with example of how to use states.

This release introduces salt states for early developers and testers to start
helping us clean up the states interface and make it ready for the world!

0.9.2 also fixes a number of bugs found on Python 2.6.

Download!
---------

The Salt source can be downloaded from the salt github site:

:download:`salt-0.9.2.tar.gz`

Or from PiPy:

http://pypi.python.org/packages/source/s/salt/salt-0.9.2.tar.gz

For instructions on how to set up Salt please see the :ref:`installation`
instructions.

New Features
------------

Salt-Call Additions
````````````````````

The salt-call command has received an overhaul, it now hooks into the outputter
system so command output looks clean, and the logging system has been hooked
into salt-call, so the -l option allows the logging output from salt minion
functions to be displayed.

The end result is that the salt-call command can execute the state system and
return clean output:

.. code-block:: bash

    # salt-call state.highstate

State System Fixes
```````````````````

The state system has been tested and better refined. As of this release the
state system is ready for early testers to start playing with. If you are
interested in working with the state system please check out the (still very
small) salt-states github repo:

https://github.com/thatch45/salt-states

This git repo is the active development branch for determining how a clean
salt-state database should look and act. Since the salt state system is still
very young a lot of help is still needed here. Please fork the salt-states
repo and help us develop a truly large and scalable system for configuration
management!

Notable Bug Fixes
-----------------

Python 2.6 String Formatting
````````````````````````````

Python 2.6 does not support format strings without an index identifier, all of
them have been repaired.

Cython Loading Disabled by Default
``````````````````````````````````

Cython loading requires a development tool chain to be installed on the minion,
requiring this by default can cause problems for most Salt deployments. If
Cython auto loading is desired it will need to be turned on in the minion
config.


